#
# spec file for package xjadeo
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xjadeo
Version:        0.8.14
Release:        bp160.1.7
Summary:        Video player that gets sync from Jack
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Visualization
URL:            http://xjadeo.sourceforge.net/
Source0:        https://sourceforge.net/projects/xjadeo/files/xjadeo/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(imlib2) >= 1.3.0
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xpm)

%description
Xjadeo is a video player that gets sync from JACK. When a
sequencer like Muse or Rosegarden acts as a timebase master, xjadeo will
display the video frame in sync with the sequencer transport. This means
that an audio event can be visually synchronized with a certain frame in
the movie, which may be useful for creating a soundtrack for
a video clip.

%prep
%autosetup -p1

%build
export CFLAGS="-Wall %{optflags}"
%configure
%make_build

%install
%make_install

install -Dm644 src/%{name}/icons/%{name}H128.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%suse_update_desktop_file -c %{name} %{name} "The X Jack Video Monitor" %{name} %{name} AudioVideo Video Player

%files
%doc README NEWS AUTHORS ChangeLog
%license COPYING
%{_bindir}/%{name}
%{_bindir}/xjremote
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man1/xjremote.1%{ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/ArdourMono.ttf

%changelog
* Sun Apr 28 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.14:
  * Fix JACK Transport when using pipewire
  * Update build-script (disable QT GUI)
* Sun Nov 19 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.13:
  * wrap-around/loop: fix modulo calculation (by trinitou)
  * Add Xinerama support (linux, by Ion Reguera)
  * Update build-scripts, fix macOS portmidi support
* Sun Jan  1 2023 Edgar Aichinger <edogawa@aon.at>
- Update to version 0.8.12:
  * add compatibility for ffmpeg-5.1
  * fix UI scale when building on 10.15 or later
- Drop 973f0046.patch (now upstream)
* Sun Sep  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 973f0046.patch: ffmpeg 5.1 compatibility.
* Tue Jul 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.8.11:
  * Add compatibility for ffmpeg-5.0
  * Update static-builder to use ffmpeg-5.0
  * Add support for modern mingw (pthread)
  * Update git clone URIs - avoid git://
* Wed Jan 27 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.10
  * add keyboard shortcuts for +/- 1 second offsets
  * fix Linux gcc10 builds
- Drop xjadeo-gcc10.patch (merged upstream)
* Mon Jun  8 2020 Luigi Baldoni <aloisio@gmx.com>
- Add xjadeo-gcc10.patch
* Sat Nov  2 2019 Luigi Baldoni <aloisio@gmx.com>
- Add pkgconfig(xext) as BR to fix Factory build
* Mon Apr 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.8.9
  * prefer -pthread over -lpthread, fixes #18
  * mainly a build-system, binary only update
  version 0.8.8
  * use PortMidi default device (allow using portmidisetup)
* Mon Mar 12 2018 jengelh@inai.de
- Ensure neutrality of description.
* Sat Mar 10 2018 aloisio@gmx.com
- Update to version 0.8.7
  * fix release builds (mistake in 0.8.6)
  version 0.8.6
  * weak-link against libjack (binaries)
  version 0.8.5
  * release openGL context
  * add compatibility for ffmpeg-2.9
  version 0.8.3
  * defined LARGEFILE64 for huge videos
- Spec cleanup
* Mon Oct  5 2015 avvissu@yandex.ru
- Update to 0.8.2:
  * see: /usr/share/doc/packages/xjadeo/ChangeLog
- Del pkgconfig(QtGui):
  * qjadeo is deprecated an not intended to be used
- Remove xjadeo.desktop: use %%%%suse_update_desktop_file
- Use a detailed list of files
- Spec file cleanup
* Sun Aug 24 2014 edogawa@aon.at
- initial release, version 0.8.0
- based on Fedora/Planet CCRMA specfile
